
<div class="container my-5">
    <h2 class="text-center mb-4 fw-bold text-primary">Libros, articulos y más información</h2>

    <!-- Buscador -->
    <form method="get" class="mb-4">
        <div class="row g-3">
            <!-- Buscar por título o autor -->
            <div class="col-md-4">
                <input type="text" name="search" class="form-control" placeholder="Buscar por título o autor">
            </div>
            <!-- Buscar por categoría -->
            <div class="col-md-4">
                <select name="category" class="form-select">
                    <option value="">Selecciona una categoría</option>
                    <?php 
                    // Obtener categorías únicas desde el modelo
                    $categorias = array_unique(array_column($libros, 'categoria'));
                    foreach ($categorias as $categoria): ?>
                        <option value="<?= esc($categoria); ?>"><?= esc($categoria); ?></option>
                    <?php endforeach; ?>
                </select>
            </div>
            <!-- Botón de búsqueda -->
            <div class="col-md-2">
                <button type="submit" class="btn btn-primary w-100">Buscar</button>
            </div>
        </div>
    </form>

    <!-- Lista de Libros -->
    <div class="row">
        <?php foreach ($libros as $index => $libro): ?>
            <div class="col-md-6 mb-4">
                <div class="card h-100 shadow-sm">
                    <div class="row g-0">
                        <!-- Imagen del libro -->
                        <div class="col-md-4 text-center p-2">
                            <a href="#" data-bs-toggle="modal" data-bs-target="#modalLibro<?= $index; ?>">
                                <img src="<?= base_url('images/' . $libro['imagen']) ?>" 
                                     alt="<?= esc($libro['titulo']); ?>"
                                     class="img-fluid rounded shadow" style="max-height: 250px; object-fit: cover;">
                            </a>
                        </div>
                        <!-- Detalles del libro -->
                        <div class="col-md-8">
                            <div class="card-body">
                                <h5 class="card-title text-primary fw-bold"><?= esc($libro['titulo']); ?></h5>
                                <p class="card-text mb-1"><strong>Autor:</strong> <?= esc($libro['autor']); ?></p>
                                <p class="card-text mb-1"><strong>Editorial:</strong> <?= esc($libro['editorial']); ?></p>
                                <p class="card-text mb-1"><strong>Categoría:</strong> <?= esc($libro['categoria']); ?></p>
                                <p class="card-text"><strong>Año:</strong> <?= esc($libro['año_edicion']); ?></p>
                            </div>
                        </div>
                    </div>
                </div>
            </div>

            <!-- Modal para previsualizar el documento -->
            <div class="modal fade" id="modalLibro<?= $index; ?>" tabindex="-1" aria-hidden="true">
                <div class="modal-dialog modal-lg">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title"><?= esc($libro['titulo']); ?></h5>
                            <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                        </div>
                        <div class="modal-body">
                            <!-- Previsualización del documento PDF -->
                            <iframe src="<?= base_url('documents/' . $libro['documento']) ?>" 
                                    style="width: 100%; height: 500px; border: none;"></iframe>
                        </div>
                        <div class="modal-footer">
                            <!-- Botón Descargar -->
                            <a href="<?= base_url('documents/' . $libro['documento']) ?>" class="btn btn-primary" download>Descargar</a>
                            <button onclick="printPDF('<?= base_url('documents/' . $libro['documento']) ?>')" class="btn btn-secondary">Imprimir</button>
                            <button class="btn btn-danger" data-bs-dismiss="modal">Cerrar</button>
                        </div>
                    </div>
                </div>
            </div>
        <?php endforeach; ?>
    </div>

    <?php if (empty($libros)): ?>
        <p class="text-center text-muted">No se encontraron libros.</p>
    <?php endif; ?>
</div>

<!-- Script para Imprimir PDF -->
<script>
    function printPDF(url) {
        var iframe = document.createElement('iframe');
        iframe.style.display = 'none';
        iframe.src = url;
        document.body.appendChild(iframe);
        iframe.contentWindow.focus();
        iframe.contentWindow.print();
    }
</script>
